# MyOrderFunctions.py
# Chapter 4
# pages 45-47

# 3 ways to import objects with the import keyword
# import ModuleName
## ModuleName is the filename without the .py extension
# from ModuleName import ObjectName
from datetime import date
# import ModuleName as Namespace/Alias
# import datetime as dt

# csv Python Standard Module
## Python Standard Modules are installed when you install Python using the python.org website installer BUT you need to use the import keyword to import the objects to your code
## Python Core Modules are installed when you install Python using the python.org website installer, input(), int(), print(), str(), open(), ... BUT you DO NOT need to use the import keyword
## Python PIP Module (Python Installation Package) are NOT installed with Core. You need to use the pip install command to install these types of modules and commonly need to use the import keyword to use the objects. pypi.org
## Python Custom Modules are your modules, they are not relative to the python.org website

import csv # Python Standard Module

# data
orders = [
    {'orderid': 1001, 'orderdate': date(2024, 7, 14), 'ordertotal': 150.71},
    {'orderid': 1002, 'orderdate': date(2024, 7, 21), 'ordertotal': 25.42},
    {'orderid': 1003, 'orderdate': date(2024, 8, 4), 'ordertotal': 125.21},
    {'orderid': 1004, 'orderdate': date(2024, 8, 10), 'ordertotal': 51.24}
]

filename = "orders.csv"

# write order data to csv file
def write_orders_to_csv(filename, orders):
    with open(filename, 'w', newline='') as csvfile:
        fieldnames = ['orderid','orderdate','ordertotal']
        writer = csv.DictWriter(csvfile, fieldnames=fieldnames)

        #DictWriter has a built in header() for the field names
        writer.writeheader() # write the header to row[0]

        # data row[1]
        for order in orders:
            writer.writerow(order)

    print(f"Data rows have been written to {filename}.")

# read the rows from the csv file into a list in memory
def read_orders_from_csv(filename):
    ordersFromCsv = []

    with open(filename, 'r') as csvfile:
        reader = csv.DictReader(csvfile)
        # DictReader() has a built in next() to skip row[0]
        # reader() need a next() if we had a header row in our dataset

        # for x in ys > ys is the buffer with the dataset
        for row in reader:
            # Convert the string inputs to the correct data type for the application
            row['orderid'] = int(row['orderid']) 
            # 'orderid': 1004
            row['orderdate'] = date.fromisoformat(row['orderdate'])
            row['ordertotal'] = float(row['ordertotal'])
            #  {'orderid': 1004, 'orderdate': date(2024, 8, 10), 'ordertotal': 51.24 }
            ordersFromCsv.append(row)

    return orders # make the orders[] avaiable in the program
    # define a variable somewhere that is assigned to this return